==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/OrgContactTypeObj.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonSubTypes;
import com.fasterxml.jackson.annotation.JsonTypeInfo;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.OrgBillingContactType;
import com.okta.sdk.resource.model.OrgContactType;
import com.okta.sdk.resource.model.OrgTechnicalContactType;
import com.okta.sdk.resource.model.OrgTechnicalContactTypeLinks;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * OrgContactTypeObj
 */
@JsonPropertyOrder({ OrgContactTypeObj.JSON_PROPERTY_CONTACT_TYPE, OrgContactTypeObj.JSON_PROPERTY_LINKS })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
@JsonTypeInfo(use = JsonTypeInfo.Id.NAME, include = JsonTypeInfo.As.EXISTING_PROPERTY, property = "contactType", visible = true, defaultImpl = OrgContactTypeObj.class)
@JsonSubTypes({ @JsonSubTypes.Type(value = OrgBillingContactType.class, name = "BILLING"),
        @JsonSubTypes.Type(value = OrgTechnicalContactType.class, name = "TECHNICAL"),
        @JsonSubTypes.Type(value = OrgBillingContactType.class, name = "orgBillingContactType"),
        @JsonSubTypes.Type(value = OrgTechnicalContactType.class, name = "orgTechnicalContactType"), })

public class OrgContactTypeObj implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_CONTACT_TYPE = "contactType";
    protected OrgContactType contactType;

    public static final String JSON_PROPERTY_LINKS = "_links";
    private OrgTechnicalContactTypeLinks links;

    public OrgContactTypeObj() {
    }

    public OrgContactTypeObj contactType(OrgContactType contactType) {

        this.contactType = contactType;
        return this;
    }

    /**
     * Get contactType
     *
     * @return contactType
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CONTACT_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public OrgContactType getContactType() {
        return contactType;
    }

    @JsonProperty(JSON_PROPERTY_CONTACT_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setContactType(OrgContactType contactType) {
        this.contactType = contactType;
    }

    public OrgContactTypeObj links(OrgTechnicalContactTypeLinks links) {

        this.links = links;
        return this;
    }

    /**
     * Get links
     *
     * @return links
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_LINKS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public OrgTechnicalContactTypeLinks getLinks() {
        return links;
    }

    @JsonProperty(JSON_PROPERTY_LINKS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setLinks(OrgTechnicalContactTypeLinks links) {
        this.links = links;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        OrgContactTypeObj orgContactTypeObj = (OrgContactTypeObj) o;
        return Objects.equals(this.contactType, orgContactTypeObj.contactType)
                && Objects.equals(this.links, orgContactTypeObj.links);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(contactType, links);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class OrgContactTypeObj {\n");
        sb.append("    contactType: ").append(toIndentedString(contactType)).append("\n");
        sb.append("    links: ").append(toIndentedString(links)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/OrgContactTypeObj.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonSubTypes;
import com.fasterxml.jackson.annotation.JsonTypeInfo;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.OrgBillingContactType;
import com.okta.sdk.resource.model.OrgContactType;
import com.okta.sdk.resource.model.OrgTechnicalContactType;
import com.okta.sdk.resource.model.OrgTechnicalContactTypeLinks;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * OrgContactTypeObj
 */
@JsonPropertyOrder({ OrgContactTypeObj.JSON_PROPERTY_CONTACT_TYPE, OrgContactTypeObj.JSON_PROPERTY_LINKS })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
@JsonTypeInfo(use = JsonTypeInfo.Id.NAME, include = JsonTypeInfo.As.EXISTING_PROPERTY, property = "contactType", visible = true, defaultImpl = OrgContactTypeObj.class)
@JsonSubTypes({ @JsonSubTypes.Type(value = OrgBillingContactType.class, name = "BILLING"),
        @JsonSubTypes.Type(value = OrgTechnicalContactType.class, name = "TECHNICAL"),
        @JsonSubTypes.Type(value = OrgBillingContactType.class, name = "orgBillingContactType"),
        @JsonSubTypes.Type(value = OrgTechnicalContactType.class, name = "orgTechnicalContactType"), })

public class OrgContactTypeObj implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_CONTACT_TYPE = "contactType";
    protected OrgContactType contactType;

    public static final String JSON_PROPERTY_LINKS = "_links";
    private OrgTechnicalContactTypeLinks links;

    public OrgContactTypeObj() {
    }

    public OrgContactTypeObj contactType(OrgContactType contactType) {

        this.contactType = contactType;
        return this;
    }

    /**
     * Get contactType
     *
     * @return contactType
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CONTACT_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public OrgContactType getContactType() {
        return contactType;
    }

    @JsonProperty(JSON_PROPERTY_CONTACT_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setContactType(OrgContactType contactType) {
        this.contactType = contactType;
    }

    public OrgContactTypeObj links(OrgTechnicalContactTypeLinks links) {

        this.links = links;
        return this;
    }

    /**
     * Get links
     *
     * @return links
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_LINKS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public OrgTechnicalContactTypeLinks getLinks() {
        return links;
    }

    @JsonProperty(JSON_PROPERTY_LINKS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setLinks(OrgTechnicalContactTypeLinks links) {
        this.links = links;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        OrgContactTypeObj orgContactTypeObj = (OrgContactTypeObj) o;
        return Objects.equals(this.contactType, orgContactTypeObj.contactType)
                && Objects.equals(this.links, orgContactTypeObj.links);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(contactType, links);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class OrgContactTypeObj {\n");
        sb.append("    contactType: ").append(toIndentedString(contactType)).append("\n");
        sb.append("    links: ").append(toIndentedString(links)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
